from AuthX.services.admin import AdminService
from AuthX.services.auth import AuthService
from AuthX.services.password import PasswordService
from AuthX.services.search import SearchService
from AuthX.services.social import SocialService

"""
    Initialize all services
"""

__all__ = [
    "AdminService",
    "AuthService",
    "PasswordService",
    "SearchService",
    "SocialService",
]
